@@ -1,10 +1,11 @@
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Sequence, Tuple, get_args
 
 from google.protobuf.json_format import MessageToDict
 from google.protobuf.timestamp_pb2 import Timestamp
 
 from arc_vector_client._pydantic_compat import construct
+from arc_vector_client.conversions.common_types import get_args_subscribed
 
 try:
     from google.protobuf.pyext._message import MessageMapContainer  # type: ignore
@@ -83,6 +84,8 @@ def grpc_payload_schema_to_field_type(model: grpc.PayloadSchemaType) -> grpc.Fie
         return grpc.FieldType.FieldTypeInteger
     if model == grpc.PayloadSchemaType.Float:
         return grpc.FieldType.FieldTypeFloat
+    if model == grpc.PayloadSchemaType.Bool:
+        return grpc.FieldType.FieldTypeBool
     if model == grpc.PayloadSchemaType.Geo:
         return grpc.FieldType.FieldTypeGeo
     if model == grpc.PayloadSchemaType.Text:
@@ -98,6 +101,8 @@ def grpc_field_type_to_payload_schema(model: grpc.FieldType) -> grpc.PayloadSche
         return grpc.PayloadSchemaType.Integer
     if model == grpc.FieldType.FieldTypeFloat:
         return grpc.PayloadSchemaType.Float
+    if model == grpc.FieldType.FieldTypeBool:
+        return grpc.PayloadSchemaType.Bool
     if model == grpc.FieldType.FieldTypeGeo:
         return grpc.PayloadSchemaType.Geo
     if model == grpc.FieldType.FieldTypeText:
@@ -301,6 +306,8 @@ class GrpcToRest:
             return rest.PayloadSchemaType.INTEGER
         elif model == grpc.PayloadSchemaType.Keyword:
             return rest.PayloadSchemaType.KEYWORD
+        elif model == grpc.PayloadSchemaType.Bool:
+            return rest.PayloadSchemaType.BOOL
         elif model == grpc.PayloadSchemaType.Text:
             return rest.PayloadSchemaType.TEXT
         else:
@@ -382,6 +389,7 @@ class GrpcToRest:
             quantization=cls.convert_quantization_search_params(model.quantization)
             if model.HasField("quantization")
             else None,
+            indexed_only=model.indexed_only if model.HasField("indexed_only") else None,
         )
 
     @classmethod
@@ -511,6 +519,9 @@ class GrpcToRest:
             replication_factor=model.replication_factor
             if model.HasField("replication_factor")
             else None,
+            read_fan_out_factor=model.read_fan_out_factor
+            if model.HasField("read_fan_out_factor")
+            else None,
             write_consistency_factor=model.write_consistency_factor
             if model.HasField("write_consistency_factor")
             else None,
@@ -550,9 +561,21 @@ class GrpcToRest:
     @classmethod
     def convert_update_collection(cls, model: grpc.UpdateCollection) -> rest.UpdateCollection:
         return rest.UpdateCollection(
+            vectors=cls.convert_vectors_config_diff(model.vectors_config)
+            if model.HasField("vectors_config")
+            else None,
             optimizers_config=cls.convert_optimizers_config_diff(model.optimizers_config)
             if model.HasField("optimizers_config")
-            else None
+            else None,
+            params=cls.convert_collection_params_diff(model.params)
+            if model.HasField("params")
+            else None,
+            hnsw_config=cls.convert_hnsw_config_diff(model.hnsw_config)
+            if model.HasField("hnsw_config")
+            else None,
+            quantization_config=cls.convert_quantization_config_diff(model.quantization_config)
+            if model.HasField("quantization_config")
+            else None,
         )
 
     @classmethod
@@ -722,9 +745,15 @@ class GrpcToRest:
 
     @classmethod
     def convert_recommend_points(cls, model: grpc.RecommendPoints) -> rest.RecommendRequest:
+        positive_ids = [cls.convert_point_id(point_id) for point_id in model.positive]
+        negative_ids = [cls.convert_point_id(point_id) for point_id in model.negative]
+
+        positive_vectors = [cls.convert_vector(vector) for vector in model.positive_vectors]
+        negative_vectors = [cls.convert_vector(vector) for vector in model.negative_vectors]
+
         return rest.RecommendRequest(
-            positive=[cls.convert_point_id(point_id) for point_id in model.positive],
-            negative=[cls.convert_point_id(point_id) for point_id in model.negative],
+            positive=positive_ids + positive_vectors,
+            negative=negative_ids + negative_vectors,
             filter=cls.convert_filter(model.filter) if model.HasField("filter") else None,
             limit=model.limit,
             with_payload=cls.convert_with_payload_interface(model.with_payload)
@@ -740,6 +769,9 @@ class GrpcToRest:
             lookup_from=cls.convert_lookup_location(model.lookup_from)
             if model.HasField("lookup_from")
             else None,
+            strategy=cls.convert_recommend_strategy(model.strategy)
+            if model.HasField("strategy")
+            else None,
         )
 
     @classmethod
@@ -750,6 +782,8 @@ class GrpcToRest:
             return rest.TokenizerType.WHITESPACE
         if model == grpc.Word:
             return rest.TokenizerType.WORD
+        if model == grpc.Multilingual:
+            return rest.TokenizerType.MULTILINGUAL
         raise ValueError(f"invalid TokenizerType model: {model}")  # pragma: no cover
 
     @classmethod
@@ -773,6 +807,10 @@ class GrpcToRest:
             write_consistency_factor=model.write_consistency_factor
             if model.HasField("write_consistency_factor")
             else None,
+            read_fan_out_factor=model.read_fan_out_factor
+            if model.HasField("read_fan_out_factor")
+            else None,
+            on_disk_payload=model.on_disk_payload if model.HasField("on_disk_payload") else None,
         )
 
     @classmethod
@@ -833,6 +871,14 @@ class GrpcToRest:
             always_ram=model.always_ram if model.HasField("always_ram") else None,
         )
 
+    @classmethod
+    def convert_binary_quantization_config(
+        cls, model: grpc.BinaryQuantization
+    ) -> rest.BinaryQuantizationConfig:
+        return rest.BinaryQuantizationConfig(
+            always_ram=model.always_ram if model.HasField("always_ram") else None,
+        )
+
     @classmethod
     def convert_compression_ratio(cls, model: grpc.CompressionRatio) -> rest.CompressionRatio:
         if model == grpc.x4:
@@ -857,6 +903,8 @@ class GrpcToRest:
             return rest.ScalarQuantization(scalar=cls.convert_scalar_quantization_config(val))
         if name == "product":
             return rest.ProductQuantization(product=cls.convert_product_quantization_config(val))
+        if name == "binary":
+            return rest.BinaryQuantization(binary=cls.convert_binary_quantization_config(val))
         raise ValueError(f"invalid QuantizationConfig model: {model}")  # pragma: no cover
 
     @classmethod
@@ -908,6 +956,168 @@ class GrpcToRest:
             else None,
         )
 
+    @classmethod
+    def convert_quantization_config_diff(
+        cls, model: grpc.QuantizationConfigDiff
+    ) -> rest.QuantizationConfigDiff:
+        name = model.WhichOneof("quantization")
+        val = getattr(model, name)
+        if name == "scalar":
+            return rest.ScalarQuantization(scalar=cls.convert_scalar_quantization_config(val))
+        if name == "product":
+            return rest.ProductQuantization(product=cls.convert_product_quantization_config(val))
+        if name == "binary":
+            return rest.BinaryQuantization(binary=cls.convert_binary_quantization_config(val))
+        if name == "disabled":
+            return rest.Disabled.DISABLED
+        raise ValueError(f"invalid QuantizationConfigDiff model: {model}")  # pragma: no cover
+
+    @classmethod
+    def convert_vector_params_diff(cls, model: grpc.VectorParamsDiff) -> rest.VectorParamsDiff:
+        return rest.VectorParamsDiff(
+            hnsw_config=cls.convert_hnsw_config_diff(model.hnsw_config)
+            if model.HasField("hnsw_config")
+            else None,
+            quantization_config=cls.convert_quantization_config_diff(model.quantization_config)
+            if model.HasField("quantization_config")
+            else None,
+            on_disk=model.on_disk if model.HasField("on_disk") else None,
+        )
+
+    @classmethod
+    def convert_vectors_config_diff(cls, model: grpc.VectorsConfigDiff) -> rest.VectorsConfigDiff:
+        name = model.WhichOneof("config")
+        val = getattr(model, name)
+
+        if name == "params":
+            return {"": cls.convert_vector_params_diff(val)}
+        if name == "params_map":
+            return dict(
+                (key, cls.convert_vector_params_diff(vec_params))
+                for key, vec_params in val.map.items()
+            )
+        raise ValueError(f"invalid VectorsConfigDiff model: {model}")  # pragma: no cover
+
+    @classmethod
+    def convert_points_update_operation(
+        cls, model: grpc.PointsUpdateOperation
+    ) -> rest.UpdateOperation:
+        name = model.WhichOneof("operation")
+        val = getattr(model, name)
+
+        if name == "upsert":
+            return rest.UpsertOperation(
+                upsert=rest.PointsList(
+                    points=[cls.convert_point_struct(point) for point in val.points]
+                )
+            )
+        elif name == "delete":
+            return rest.DeleteOperation(delete=cls.convert_points_selector(val))
+        elif name == "set_payload":
+            points_selector = cls.convert_points_selector(val.points_selector)
+            points = None
+            filter_ = None
+            if isinstance(points_selector, rest.PointIdsList):
+                points = points_selector.points
+            elif isinstance(points_selector, rest.FilterSelector):
+                filter_ = points_selector.filter
+            else:
+                raise ValueError(
+                    f"invalid PointsSelector model: {points_selector}"
+                )  # pragma: no cover
+
+            return rest.SetPayloadOperation(
+                set_payload=rest.SetPayload(
+                    payload=cls.convert_payload(val.payload),
+                    points=points,
+                    filter=filter_,
+                )
+            )
+        elif name == "overwrite_payload":
+            points_selector = cls.convert_points_selector(val.points_selector)
+            points = None
+            filter_ = None
+            if isinstance(points_selector, rest.PointIdsList):
+                points = points_selector.points
+            elif isinstance(points_selector, rest.FilterSelector):
+                filter_ = points_selector.filter
+            else:
+                raise ValueError(
+                    f"invalid PointsSelector model: {points_selector}"
+                )  # pragma: no cover
+
+            return rest.OverwritePayloadOperation(
+                overwrite_payload=rest.SetPayload(
+                    payload=cls.convert_payload(val.payload),
+                    points=points,
+                    filter=filter_,
+                )
+            )
+        elif name == "delete_payload":
+            points_selector = cls.convert_points_selector(val.points_selector)
+            points = None
+            filter_ = None
+            if isinstance(points_selector, rest.PointIdsList):
+                points = points_selector.points
+            elif isinstance(points_selector, rest.FilterSelector):
+                filter_ = points_selector.filter
+            else:
+                raise ValueError(
+                    f"invalid PointsSelector model: {points_selector}"
+                )  # pragma: no cover
+
+            return rest.DeletePayloadOperation(
+                delete_payload=rest.DeletePayload(
+                    keys=[key for key in val.keys],
+                    points=points,
+                    filter=filter_,
+                )
+            )
+        elif name == "clear_payload":
+            return rest.ClearPayloadOperation(clear_payload=cls.convert_points_selector(val))
+        elif name == "update_vectors":
+            return rest.UpdateVectorsOperation(
+                update_vectors=rest.UpdateVectors(
+                    points=[cls.convert_point_vectors(point) for point in val.points]
+                )
+            )
+        elif name == "delete_vectors":
+            points_selector = cls.convert_points_selector(val.points_selector)
+            points = None
+            filter_ = None
+            if isinstance(points_selector, rest.PointIdsList):
+                points = points_selector.points
+            elif isinstance(points_selector, rest.FilterSelector):
+                filter_ = points_selector.filter
+            else:
+                raise ValueError(
+                    f"invalid PointsSelector model: {points_selector}"
+                )  # pragma: no cover
+
+            return rest.DeleteVectorsOperation(
+                delete_vectors=rest.DeleteVectors(
+                    vector=[name for name in val.vectors.names],
+                    points=points,
+                    filter=filter_,
+                )
+            )
+        else:
+            raise ValueError(f"invalid UpdateOperation model: {model}")  # pragma: no cover
+
+    @classmethod
+    def convert_init_from(cls, model: str) -> rest.InitFrom:
+        if isinstance(model, str):
+            return rest.InitFrom(collection=model)
+        raise ValueError(f"Invalid InitFrom model: {model}")
+
+    @classmethod
+    def convert_recommend_strategy(cls, model: grpc.RecommendStrategy) -> rest.RecommendStrategy:
+        if model == grpc.RecommendStrategy.AverageVector:
+            return rest.RecommendStrategy.AVERAGE_VECTOR
+        if model == grpc.RecommendStrategy.BestScore:
+            return rest.RecommendStrategy.BEST_SCORE
+        raise ValueError(f"invalid RecommendStrategy model: {model}")
+
 
 # ----------------------------------------
 #
@@ -1017,6 +1227,8 @@ class RestToGrpc:
             return grpc.PayloadSchemaType.Integer
         if model == rest.PayloadSchemaType.FLOAT:
             return grpc.PayloadSchemaType.Float
+        if model == rest.PayloadSchemaType.BOOL:
+            return grpc.PayloadSchemaType.Bool
         if model == rest.PayloadSchemaType.GEO:
             return grpc.PayloadSchemaType.Geo
         if model == rest.PayloadSchemaType.TEXT:
@@ -1079,6 +1291,7 @@ class RestToGrpc:
             quantization=cls.convert_quantization_search_params(model.quantization)
             if model.quantization is not None
             else None,
+            indexed_only=model.indexed_only,
         )
 
     @classmethod
@@ -1237,6 +1450,7 @@ class RestToGrpc:
             on_disk_payload=model.on_disk_payload or False,
             write_consistency_factor=model.write_consistency_factor,
             replication_factor=model.replication_factor,
+            read_fan_out_factor=model.read_fan_out_factor,
         )
 
     @classmethod
@@ -1276,6 +1490,18 @@ class RestToGrpc:
             optimizers_config=cls.convert_optimizers_config_diff(model.optimizers_config)
             if model.optimizers_config is not None
             else None,
+            vectors_config=cls.convert_vectors_config_diff(model.vectors)
+            if model.vectors is not None
+            else None,
+            params=cls.convert_collection_params_diff(model.params)
+            if model.params is not None
+            else None,
+            hnsw_config=cls.convert_hnsw_config_diff(model.hnsw_config)
+            if model.hnsw_config is not None
+            else None,
+            quantization_config=cls.convert_quantization_config_diff(model.quantization_config)
+            if model.quantization_config is not None
+            else None,
         )
 
     @classmethod
@@ -1330,6 +1556,40 @@ class RestToGrpc:
             collection_name=model.collection_name,
         )
 
+    @classmethod
+    def convert_recommend_examples_to_ids(
+        cls, examples: Sequence[rest.RecommendExample]
+    ) -> List[grpc.PointId]:
+        ids: List[grpc.PointId] = []
+        for example in examples:
+            if isinstance(example, get_args_subscribed(rest.ExtendedPointId)):
+                id_ = cls.convert_extended_point_id(example)
+            elif isinstance(example, grpc.PointId):
+                id_ = example
+            else:
+                continue
+
+            ids.append(id_)
+
+        return ids
+
+    @classmethod
+    def convert_recommend_examples_to_vectors(
+        cls, examples: Sequence[rest.RecommendExample]
+    ) -> List[grpc.Vector]:
+        vectors: List[grpc.Vector] = []
+        for example in examples:
+            if isinstance(example, grpc.Vector):
+                vector = example
+            elif isinstance(example, list):
+                vector = grpc.Vector(data=example)
+            else:
+                continue
+
+            vectors.append(vector)
+
+        return vectors
+
     @classmethod
     def convert_extended_point_id(cls, model: rest.ExtendedPointId) -> grpc.PointId:
         if isinstance(model, int):
@@ -1393,13 +1653,7 @@ class RestToGrpc:
             return grpc.WithPayloadSelector(enable=model)
         elif isinstance(model, list):
             return grpc.WithPayloadSelector(include=grpc.PayloadIncludeSelector(fields=model))
-        elif isinstance(
-            model,
-            (
-                rest.PayloadSelectorInclude,
-                rest.PayloadSelectorExclude,
-            ),
-        ):
+        elif isinstance(model, get_args(rest.PayloadSelector)):
             return cls.convert_payload_selector(model)
 
         raise ValueError(f"invalid WithPayloadInterface model: {model}")  # pragma: no cover
@@ -1540,10 +1794,16 @@ class RestToGrpc:
     def convert_recommend_request(
         cls, model: rest.RecommendRequest, collection_name: str
     ) -> grpc.RecommendPoints:
+        positive_ids = cls.convert_recommend_examples_to_ids(model.positive)
+        negative_ids = cls.convert_recommend_examples_to_ids(model.negative)
+
+        positive_vectors = cls.convert_recommend_examples_to_vectors(model.positive)
+        negative_vectors = cls.convert_recommend_examples_to_vectors(model.negative)
+
         return grpc.RecommendPoints(
             collection_name=collection_name,
-            positive=[cls.convert_extended_point_id(point_id) for point_id in model.positive],
-            negative=[cls.convert_extended_point_id(point_id) for point_id in model.negative],
+            positive=positive_ids,
+            negative=negative_ids,
             filter=cls.convert_filter(model.filter) if model.filter is not None else None,
             limit=model.limit,
             with_payload=cls.convert_with_payload_interface(model.with_payload)
@@ -1559,6 +1819,11 @@ class RestToGrpc:
             lookup_from=cls.convert_lookup_location(model.lookup_from)
             if model.lookup_from is not None
             else None,
+            strategy=cls.convert_recommend_strategy(model.strategy)
+            if model.strategy is not None
+            else None,
+            positive_vectors=positive_vectors,
+            negative_vectors=negative_vectors,
         )
 
     @classmethod
@@ -1575,6 +1840,8 @@ class RestToGrpc:
             return grpc.TokenizerType.Whitespace
         elif model == rest.TokenizerType.PREFIX:
             return grpc.TokenizerType.Prefix
+        elif model == rest.TokenizerType.MULTILINGUAL:
+            return grpc.TokenizerType.Multilingual
         else:
             raise ValueError(f"invalid TokenizerType model: {model}")
 
@@ -1596,6 +1863,8 @@ class RestToGrpc:
         return grpc.CollectionParamsDiff(
             replication_factor=model.replication_factor,
             write_consistency_factor=model.write_consistency_factor,
+            on_disk_payload=model.on_disk_payload,
+            read_fan_out_factor=model.read_fan_out_factor,
         )
 
     @classmethod
@@ -1661,6 +1930,14 @@ class RestToGrpc:
             always_ram=model.always_ram,
         )
 
+    @classmethod
+    def convert_binary_quantization_config(
+        cls, model: rest.BinaryQuantizationConfig
+    ) -> grpc.BinaryQuantization:
+        return grpc.BinaryQuantization(
+            always_ram=model.always_ram,
+        )
+
     @classmethod
     def convert_compression_ratio(cls, model: rest.CompressionRatio) -> grpc.CompressionRatio:
         if model == rest.CompressionRatio.X4:
@@ -1688,6 +1965,10 @@ class RestToGrpc:
             return grpc.QuantizationConfig(
                 product=cls.convert_product_quantization_config(model.product)
             )
+        if isinstance(model, rest.BinaryQuantization):
+            return grpc.QuantizationConfig(
+                binary=cls.convert_binary_quantization_config(model.binary)
+            )
         else:
             raise ValueError(f"invalid QuantizationConfig model: {model}")
 
@@ -1751,3 +2032,187 @@ class RestToGrpc:
             if model.with_payload is not None
             else None,
         )
+
+    @classmethod
+    def convert_quantization_config_diff(
+        cls, model: rest.QuantizationConfigDiff
+    ) -> grpc.QuantizationConfigDiff:
+        if isinstance(model, rest.ScalarQuantization):
+            return grpc.QuantizationConfigDiff(
+                scalar=cls.convert_scalar_quantization_config(model.scalar)
+            )
+        if isinstance(model, rest.ProductQuantization):
+            return grpc.QuantizationConfigDiff(
+                product=cls.convert_product_quantization_config(model.product)
+            )
+        if isinstance(model, rest.BinaryQuantization):
+            return grpc.QuantizationConfigDiff(
+                binary=cls.convert_binary_quantization_config(model.binary)
+            )
+        if model == rest.Disabled.DISABLED:
+            return grpc.QuantizationConfigDiff(
+                disabled=grpc.Disabled(),
+            )
+        else:
+            raise ValueError(f"invalid QuantizationConfigDiff model: {model}")
+
+    @classmethod
+    def convert_vector_params_diff(cls, model: rest.VectorParamsDiff) -> grpc.VectorParamsDiff:
+        return grpc.VectorParamsDiff(
+            hnsw_config=cls.convert_hnsw_config_diff(model.hnsw_config)
+            if model.hnsw_config is not None
+            else None,
+            quantization_config=cls.convert_quantization_config_diff(model.quantization_config)
+            if model.quantization_config is not None
+            else None,
+            on_disk=model.on_disk,
+        )
+
+    @classmethod
+    def convert_vectors_config_diff(cls, model: rest.VectorsConfigDiff) -> grpc.VectorsConfigDiff:
+        if isinstance(model, dict) and len(model) == 1 and "" in model:
+            return grpc.VectorsConfigDiff(params=cls.convert_vector_params_diff(model[""]))
+        elif isinstance(model, dict):
+            return grpc.VectorsConfigDiff(
+                params_map=grpc.VectorParamsDiffMap(
+                    map=dict(
+                        (key, cls.convert_vector_params_diff(val)) for key, val in model.items()
+                    )
+                )
+            )
+        else:
+            raise ValueError(f"invalid VectorsConfigDiff model: {model}")  # pragma: no cover
+
+    @classmethod
+    def convert_point_insert_operation(
+        cls, model: rest.PointInsertOperations
+    ) -> List[grpc.PointStruct]:
+        if isinstance(model, rest.PointsBatch):
+            vectors_batch: List[grpc.Vectors] = cls.convert_batch_vector_struct(
+                model.batch.vectors, len(model.batch.ids)
+            )
+            return [
+                grpc.PointStruct(
+                    id=RestToGrpc.convert_extended_point_id(model.batch.ids[idx]),
+                    vectors=vectors_batch[idx],
+                    payload=RestToGrpc.convert_payload(model.batch.payloads[idx])
+                    if model.batch.payloads is not None
+                    else None,
+                )
+                for idx in range(len(model.batch.ids))
+            ]
+        elif isinstance(model, rest.PointsList):
+            return [cls.convert_point_struct(point) for point in model.points]
+        else:
+            raise ValueError(f"invalid PointInsertOperations model: {model}")
+
+    @classmethod
+    def convert_update_operation(cls, model: rest.UpdateOperation) -> grpc.PointsUpdateOperation:
+        return cls.convert_points_update_operation(model)
+
+    @classmethod
+    def convert_points_update_operation(
+        cls, model: rest.UpdateOperation
+    ) -> grpc.PointsUpdateOperation:
+        points_selector: rest.PointsSelector
+
+        if isinstance(model, rest.UpsertOperation):
+            return grpc.PointsUpdateOperation(
+                upsert=grpc.PointsUpdateOperation.PointStructList(
+                    points=cls.convert_point_insert_operation(model.upsert)
+                )
+            )
+        elif isinstance(model, rest.DeleteOperation):
+            return grpc.PointsUpdateOperation(delete=cls.convert_points_selector(model.delete))
+        elif isinstance(model, rest.SetPayloadOperation):
+            if model.set_payload.points:
+                points_selector = rest.PointIdsList(points=model.set_payload.points)
+            elif model.set_payload.filter:
+                points_selector = rest.FilterSelector(filter=model.set_payload.filter)
+            else:
+                raise ValueError(f"invalid SetPayloadOperation model: {model}")  # pragma: no cover
+
+            return grpc.PointsUpdateOperation(
+                set_payload=grpc.PointsUpdateOperation.SetPayload(
+                    payload=cls.convert_payload(model.set_payload.payload),
+                    points_selector=cls.convert_points_selector(points_selector),
+                )
+            )
+        elif isinstance(model, rest.OverwritePayloadOperation):
+            if model.overwrite_payload.points:
+                points_selector = rest.PointIdsList(points=model.overwrite_payload.points)
+            elif model.overwrite_payload.filter:
+                points_selector = rest.FilterSelector(filter=model.overwrite_payload.filter)
+            else:
+                raise ValueError(
+                    f"invalid OverwritePayloadOperation model: {model}"
+                )  # pragma: no cover
+
+            return grpc.PointsUpdateOperation(
+                overwrite_payload=grpc.PointsUpdateOperation.SetPayload(
+                    payload=cls.convert_payload(model.overwrite_payload.payload),
+                    points_selector=cls.convert_points_selector(points_selector),
+                )
+            )
+        elif isinstance(model, rest.DeletePayloadOperation):
+            if model.delete_payload.points:
+                points_selector = rest.PointIdsList(points=model.delete_payload.points)
+            elif model.delete_payload.filter:
+                points_selector = rest.FilterSelector(filter=model.delete_payload.filter)
+            else:
+                raise ValueError(
+                    f"invalid DeletePayloadOperation model: {model}"
+                )  # pragma: no cover
+
+            return grpc.PointsUpdateOperation(
+                delete_payload=grpc.PointsUpdateOperation.DeletePayload(
+                    keys=model.delete_payload.keys,
+                    points_selector=cls.convert_points_selector(points_selector),
+                )
+            )
+        elif isinstance(model, rest.ClearPayloadOperation):
+            return grpc.PointsUpdateOperation(
+                clear_payload=cls.convert_points_selector(model.clear_payload)
+            )
+        elif isinstance(model, rest.UpdateVectorsOperation):
+            return grpc.PointsUpdateOperation(
+                update_vectors=grpc.PointsUpdateOperation.UpdateVectors(
+                    points=[
+                        cls.convert_point_vectors(point) for point in model.update_vectors.points
+                    ]
+                )
+            )
+        elif isinstance(model, rest.DeleteVectorsOperation):
+            if model.delete_vectors.points:
+                points_selector = rest.PointIdsList(points=model.delete_vectors.points)
+            elif model.delete_vectors.filter:
+                points_selector = rest.FilterSelector(filter=model.delete_vectors.filter)
+            else:
+                raise ValueError(
+                    f"invalid DeletePayloadOperation model: {model}"
+                )  # pragma: no cover
+
+            return grpc.PointsUpdateOperation(
+                delete_vectors=grpc.PointsUpdateOperation.DeleteVectors(
+                    points_selector=cls.convert_points_selector(points_selector),
+                    vectors=grpc.VectorsSelector(names=model.delete_vectors.vector),
+                )
+            )
+        else:
+            raise ValueError(f"invalid UpdateOperation model: {model}")
+
+    @classmethod
+    def convert_init_from(cls, model: rest.InitFrom) -> str:
+        if isinstance(model, rest.InitFrom):
+            return model.collection
+        else:
+            raise ValueError(f"invalid InitFrom model: {model}")
+
+    @classmethod
+    def convert_recommend_strategy(cls, model: rest.RecommendStrategy) -> grpc.RecommendStrategy:
+        if model == rest.RecommendStrategy.AVERAGE_VECTOR:
+            return grpc.RecommendStrategy.AverageVector
+        elif model == rest.RecommendStrategy.BEST_SCORE:
+            return grpc.RecommendStrategy.BestScore
+        else:
+            raise ValueError(f"invalid RecommendStrategy model: {model}")
