@@ -1,17 +1,12 @@
 from datetime import datetime
 from enum import Enum
-from typing import Any, Dict, List, Optional, Union
-
-try:
-    from typing import Literal
-except ImportError:
-    # Python 3.7 backport
-    from typing_extensions import Literal
+from typing import Any, Dict, List, Literal, Optional, Union
 
 from pydantic import BaseModel, Field
 from pydantic.types import StrictBool, StrictFloat, StrictInt, StrictStr
 
-Payload = Dict[Any, Any]
+Payload = Dict[str, Any]
+VectorsConfigDiff = Dict[str, "VectorParamsDiff"]
 
 
 class AbortTransferOperation(BaseModel, extra="forbid"):
@@ -44,6 +39,14 @@ class Batch(BaseModel, extra="forbid"):
     payloads: Optional[List["Payload"]] = Field(default=None, description="")
 
 
+class BinaryQuantization(BaseModel, extra="forbid"):
+    binary: "BinaryQuantizationConfig" = Field(..., description="")
+
+
+class BinaryQuantizationConfig(BaseModel, extra="forbid"):
+    always_ram: Optional[bool] = Field(default=None, description="")
+
+
 class ChangeAliasesOperation(BaseModel, extra="forbid"):
     """
     Operation for performing changes of collection aliases. Alias changes are atomic, meaning that no collection modifications can happen between alias operations.
@@ -55,6 +58,10 @@ class ChangeAliasesOperation(BaseModel, extra="forbid"):
     )
 
 
+class ClearPayloadOperation(BaseModel, extra="forbid"):
+    clear_payload: "PointsSelector" = Field(..., description="")
+
+
 class ClusterConfigTelemetry(BaseModel, extra="forbid"):
     grpc_timeout_ms: int = Field(..., description="")
     p2p: "P2pConfigTelemetry" = Field(..., description="")
@@ -161,6 +168,10 @@ class CollectionParams(BaseModel, extra="forbid"):
         default=1,
         description="Defines how many replicas should apply the operation for us to consider it successful. Increasing this number will make the collection more resilient to inconsistencies, but will also make it fail if not enough replicas are available. Does not have any performance impact.",
     )
+    read_fan_out_factor: Optional[int] = Field(
+        default=None,
+        description="Defines how many additional replicas should be processing read request at the same time. Default value is Auto, which means that fan-out will be determined automatically based on the busyness of the local replica. Having more than 0 might be useful to smooth latency spikes of individual nodes.",
+    )
     on_disk_payload: Optional[bool] = Field(
         default=False,
         description="If true - point&#x27;s payload will not be stored in memory. It will be read from the disk every time it is requested. This setting saves RAM by (slightly) increasing the response time. Note: those payload values that are involved in filtering and are indexed - remain in RAM.",
@@ -172,9 +183,24 @@ class CollectionParamsDiff(BaseModel, extra="forbid"):
     write_consistency_factor: Optional[int] = Field(
         default=None, description="Minimal number successful responses from replicas to consider operation successful"
     )
+    read_fan_out_factor: Optional[int] = Field(
+        default=None,
+        description="Fan-out every read request to these many additional remote nodes (and return first available response)",
+    )
+    on_disk_payload: Optional[bool] = Field(
+        default=None,
+        description="If true - point&#x27;s payload will not be stored in memory. It will be read from the disk every time it is requested. This setting saves RAM by (slightly) increasing the response time. Note: those payload values that are involved in filtering and are indexed - remain in RAM.",
+    )
 
 
 class CollectionStatus(str, Enum):
+    """
+    Current state of the collection. `Green` - all good. `Yellow` - optimization is running, `Red` - some operations failed and was not recovered
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     GREEN = "green"
     YELLOW = "yellow"
     RED = "red"
@@ -337,6 +363,10 @@ class DeleteAliasOperation(BaseModel, extra="forbid"):
     delete_alias: "DeleteAlias" = Field(..., description="Delete alias if exists")
 
 
+class DeleteOperation(BaseModel, extra="forbid"):
+    delete: "PointsSelector" = Field(..., description="")
+
+
 class DeletePayload(BaseModel, extra="forbid"):
     keys: List[str] = Field(..., description="List of payload keys to remove from payload")
     points: Optional[List["ExtendedPointId"]] = Field(
@@ -347,6 +377,10 @@ class DeletePayload(BaseModel, extra="forbid"):
     )
 
 
+class DeletePayloadOperation(BaseModel, extra="forbid"):
+    delete_payload: "DeletePayload" = Field(..., description="")
+
+
 class DeleteVectors(BaseModel, extra="forbid"):
     points: Optional[List["ExtendedPointId"]] = Field(
         default=None, description="Deletes values from each point in this list"
@@ -357,7 +391,22 @@ class DeleteVectors(BaseModel, extra="forbid"):
     vector: List[str] = Field(..., description="Vector names")
 
 
+class DeleteVectorsOperation(BaseModel, extra="forbid"):
+    delete_vectors: "DeleteVectors" = Field(..., description="")
+
+
+class Disabled(str, Enum):
+    DISABLED = "Disabled"
+
+
 class Distance(str, Enum):
+    """
+    Type of internal tags, build from payload Distance function types used to compare vectors
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     COSINE = "Cosine"
     EUCLID = "Euclid"
     DOT = "Dot"
@@ -389,6 +438,9 @@ class FieldCondition(BaseModel, extra="forbid"):
         default=None, description="Check if points geo location lies in a given area"
     )
     geo_radius: Optional["GeoRadius"] = Field(default=None, description="Check if geo point is within a given radius")
+    geo_polygon: Optional["GeoPolygon"] = Field(
+        default=None, description="Check if geo point is within a given polygon"
+    )
     values_count: Optional["ValuesCount"] = Field(default=None, description="Check number of values of the field")
 
 
@@ -419,6 +471,14 @@ class GeoBoundingBox(BaseModel, extra="forbid"):
     )
 
 
+class GeoLineString(BaseModel, extra="forbid"):
+    """
+    Ordered sequence of GeoPoints representing the line
+    """
+
+    points: List["GeoPoint"] = Field(..., description="Ordered sequence of GeoPoints representing the line")
+
+
 class GeoPoint(BaseModel, extra="forbid"):
     """
     Geo point payload schema
@@ -428,6 +488,21 @@ class GeoPoint(BaseModel, extra="forbid"):
     lat: float = Field(..., description="Geo point payload schema")
 
 
+class GeoPolygon(BaseModel, extra="forbid"):
+    """
+    Geo filter request  Matches coordinates inside the polygon, defined by `exterior` and `interiors`
+    """
+
+    exterior: "GeoLineString" = Field(
+        ...,
+        description="Geo filter request  Matches coordinates inside the polygon, defined by `exterior` and `interiors`",
+    )
+    interiors: Optional[List["GeoLineString"]] = Field(
+        default=None,
+        description="Interior lines (if present) bound holes within the surface each GeoLineString must consist of a minimum of 4 points, and the first and last points must be the same.",
+    )
+
+
 class GeoRadius(BaseModel, extra="forbid"):
     """
     Geo filter request  Matches coordinates inside the circle of `radius` and center with coordinates `center`
@@ -598,7 +673,7 @@ class InlineResponse20013(BaseModel, extra="forbid"):
     status: Literal[
         "ok",
     ] = Field(None, description="")
-    result: Optional["ScrollResult"] = Field(default=None, description="")
+    result: Optional[List["UpdateResult"]] = Field(default=None, description="")
 
 
 class InlineResponse20014(BaseModel, extra="forbid"):
@@ -606,7 +681,7 @@ class InlineResponse20014(BaseModel, extra="forbid"):
     status: Literal[
         "ok",
     ] = Field(None, description="")
-    result: Optional[List["ScoredPoint"]] = Field(default=None, description="")
+    result: Optional["ScrollResult"] = Field(default=None, description="")
 
 
 class InlineResponse20015(BaseModel, extra="forbid"):
@@ -614,7 +689,7 @@ class InlineResponse20015(BaseModel, extra="forbid"):
     status: Literal[
         "ok",
     ] = Field(None, description="")
-    result: Optional[List[List["ScoredPoint"]]] = Field(default=None, description="")
+    result: Optional[List["ScoredPoint"]] = Field(default=None, description="")
 
 
 class InlineResponse20016(BaseModel, extra="forbid"):
@@ -622,10 +697,18 @@ class InlineResponse20016(BaseModel, extra="forbid"):
     status: Literal[
         "ok",
     ] = Field(None, description="")
-    result: Optional["GroupsResult"] = Field(default=None, description="")
+    result: Optional[List[List["ScoredPoint"]]] = Field(default=None, description="")
 
 
 class InlineResponse20017(BaseModel, extra="forbid"):
+    time: Optional[float] = Field(default=None, description="Time spent to process this request")
+    status: Literal[
+        "ok",
+    ] = Field(None, description="")
+    result: Optional["GroupsResult"] = Field(default=None, description="")
+
+
+class InlineResponse20018(BaseModel, extra="forbid"):
     time: Optional[float] = Field(default=None, description="Time spent to process this request")
     status: Literal[
         "ok",
@@ -836,6 +919,7 @@ class OperationDurationStatistics(BaseModel, extra="forbid"):
 class OptimizerTelemetry(BaseModel, extra="forbid"):
     status: "OptimizersStatus" = Field(..., description="")
     optimizations: "OperationDurationStatistics" = Field(..., description="")
+    log: List["TrackerTelemetry"] = Field(..., description="")
 
 
 class OptimizersConfig(BaseModel, extra="forbid"):
@@ -897,6 +981,13 @@ class OptimizersConfigDiff(BaseModel, extra="forbid"):
 
 
 class OptimizersStatusOneOf(str, Enum):
+    """
+    Optimizers are reporting as expected
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     OK = "ok"
 
 
@@ -908,6 +999,10 @@ class OptimizersStatusOneOf1(BaseModel, extra="forbid"):
     error: str = Field(..., description="Something wrong happened with optimizers")
 
 
+class OverwritePayloadOperation(BaseModel, extra="forbid"):
+    overwrite_payload: "SetPayload" = Field(..., description="")
+
+
 class P2pConfigTelemetry(BaseModel, extra="forbid"):
     connection_pool_size: int = Field(..., description="")
 
@@ -940,11 +1035,19 @@ class PayloadIndexTelemetry(BaseModel, extra="forbid"):
 
 
 class PayloadSchemaType(str, Enum):
+    """
+    All possible names of payload types
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     KEYWORD = "keyword"
     INTEGER = "integer"
     FLOAT = "float"
     GEO = "geo"
     TEXT = "text"
+    BOOL = "bool"
 
 
 class PayloadSelectorExclude(BaseModel, extra="forbid"):
@@ -1030,8 +1133,8 @@ class QuantizationSearchParams(BaseModel, extra="forbid"):
         default=False, description="If true, quantized vectors are ignored. Default is false."
     )
     rescore: Optional[bool] = Field(
-        default=False,
-        description="If true, use original vectors to re-score top-k results. Might require more time in case if original vectors are stored on disk. Default is false.",
+        default=None,
+        description="If true, use original vectors to re-score top-k results. Might require more time in case if original vectors are stored on disk. If not set, arc_vector decides automatically apply rescoring or not.",
     )
     oversampling: Optional[float] = Field(
         default=None,
@@ -1071,14 +1174,24 @@ class Range(BaseModel, extra="forbid"):
 
 
 class ReadConsistencyType(str, Enum):
+    """
+    * `majority` - send N/2+1 random request and return points, which present on all of them  * `quorum` - send requests to all nodes and return points which present on majority of nodes  * `all` - send requests to all nodes and return points which present on all nodes
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     MAJORITY = "majority"
     QUORUM = "quorum"
     ALL = "all"
 
 
 class RecommendGroupsRequest(BaseModel, extra="forbid"):
-    positive: List["ExtendedPointId"] = Field(..., description="Look for vectors closest to those")
-    negative: Optional[List["ExtendedPointId"]] = Field(default=[], description="Try to avoid vectors like this")
+    positive: Optional[List["RecommendExample"]] = Field(default=[], description="Look for vectors closest to those")
+    negative: Optional[List["RecommendExample"]] = Field(default=[], description="Try to avoid vectors like this")
+    strategy: Optional["RecommendStrategy"] = Field(
+        default=None, description="How to use positive and negative examples to find the results"
+    )
     filter: Optional["Filter"] = Field(default=None, description="Look only for points which satisfies this conditions")
     params: Optional["SearchParams"] = Field(default=None, description="Additional search params")
     with_payload: Optional["WithPayloadInterface"] = Field(
@@ -1112,11 +1225,14 @@ class RecommendGroupsRequest(BaseModel, extra="forbid"):
 
 class RecommendRequest(BaseModel, extra="forbid"):
     """
-    Recommendation request. Provides positive and negative examples of the vectors, which are already stored in the collection.  Service should look for the points which are closer to positive examples and at the same time further to negative examples. The concrete way of how to compare negative and positive distances is up to implementation in `segment` crate.
+    Recommendation request. Provides positive and negative examples of the vectors, which can be ids of points that are already stored in the collection, raw vectors, or even ids and vectors combined.  Service should look for the points which are closer to positive examples and at the same time further to negative examples. The concrete way of how to compare negative and positive distances is up to the `strategy` chosen.
     """
 
-    positive: List["ExtendedPointId"] = Field(..., description="Look for vectors closest to those")
-    negative: Optional[List["ExtendedPointId"]] = Field(default=[], description="Try to avoid vectors like this")
+    positive: Optional[List["RecommendExample"]] = Field(default=[], description="Look for vectors closest to those")
+    negative: Optional[List["RecommendExample"]] = Field(default=[], description="Try to avoid vectors like this")
+    strategy: Optional["RecommendStrategy"] = Field(
+        default=None, description="How to use positive and negative examples to find the results"
+    )
     filter: Optional["Filter"] = Field(default=None, description="Look only for points which satisfies this conditions")
     params: Optional["SearchParams"] = Field(default=None, description="Additional search params")
     limit: int = Field(..., description="Max number of result to return")
@@ -1148,6 +1264,18 @@ class RecommendRequestBatch(BaseModel, extra="forbid"):
     searches: List["RecommendRequest"] = Field(..., description="")
 
 
+class RecommendStrategy(str, Enum):
+    """
+    How to use positive and negative examples to find the results, default is `average_vector`:  * `average_vector` - Average positive and negative vectors and create a single query with the formula `query = avg_pos + avg_pos - avg_neg`. Then performs normal search.  * `best_score` - Uses custom search objective. Each candidate is compared against all examples, its score is then chosen from the `max(max_pos_score, max_neg_score)`. If the `max_neg_score` is chosen then it is squared and negated, otherwise it is just the `max_pos_score`.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
+    AVERAGE_VECTOR = "average_vector"
+    BEST_SCORE = "best_score"
+
+
 class Record(BaseModel, extra="forbid"):
     """
     Point data
@@ -1201,6 +1329,13 @@ class ReplicaSetTelemetry(BaseModel, extra="forbid"):
 
 
 class ReplicaState(str, Enum):
+    """
+    State of the single shard within a replica set.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     ACTIVE = "Active"
     DEAD = "Dead"
     PARTIAL = "Partial"
@@ -1327,6 +1462,10 @@ class SearchParams(BaseModel, extra="forbid"):
         description="Search without approximation. If set to true, search may run long but with exact results.",
     )
     quantization: Optional["QuantizationSearchParams"] = Field(default=None, description="Quantization params")
+    indexed_only: Optional[bool] = Field(
+        default=False,
+        description="If enabled, the engine will only perform search among indexed or small segments. Using this option prevents slow searches in case of delayed index, but does not guarantee that all uploaded vectors will be included in search results",
+    )
 
 
 class SearchRequest(BaseModel, extra="forbid"):
@@ -1374,11 +1513,13 @@ class SegmentInfo(BaseModel, extra="forbid"):
     segment_type: "SegmentType" = Field(..., description="Aggregated information about segment")
     num_vectors: int = Field(..., description="Aggregated information about segment")
     num_points: int = Field(..., description="Aggregated information about segment")
+    num_indexed_vectors: int = Field(..., description="Aggregated information about segment")
     num_deleted_vectors: int = Field(..., description="Aggregated information about segment")
     ram_usage_bytes: int = Field(..., description="Aggregated information about segment")
     disk_usage_bytes: int = Field(..., description="Aggregated information about segment")
     is_appendable: bool = Field(..., description="Aggregated information about segment")
     index_schema: Dict[str, "PayloadIndexInfo"] = Field(..., description="Aggregated information about segment")
+    vector_data: Dict[str, "VectorDataInfo"] = Field(..., description="Aggregated information about segment")
 
 
 class SegmentTelemetry(BaseModel, extra="forbid"):
@@ -1389,6 +1530,13 @@ class SegmentTelemetry(BaseModel, extra="forbid"):
 
 
 class SegmentType(str, Enum):
+    """
+    Type of segment
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     PLAIN = "plain"
     INDEXED = "indexed"
     SPECIAL = "special"
@@ -1404,6 +1552,15 @@ class SetPayload(BaseModel, extra="forbid"):
     )
 
 
+class SetPayloadOperation(BaseModel, extra="forbid"):
+    set_payload: "SetPayload" = Field(..., description="")
+
+
+class ShardSnapshotRecover(BaseModel, extra="forbid"):
+    location: "ShardSnapshotLocation" = Field(..., description="")
+    priority: Optional["SnapshotPriority"] = Field(default=None, description="")
+
+
 class ShardTransferInfo(BaseModel, extra="forbid"):
     shard_id: int = Field(..., description="")
     from_: int = Field(..., description="", alias="from")
@@ -1421,6 +1578,14 @@ class SnapshotDescription(BaseModel, extra="forbid"):
 
 
 class SnapshotPriority(str, Enum):
+    """
+    Defines source of truth for snapshot recovery: `NoSync` means - restore snapshot without *any* additional synchronization. `Snapshot` means - prefer snapshot data over the current state. `Replica` means - prefer existing data over the snapshot.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
+    NO_SYNC = "no_sync"
     SNAPSHOT = "snapshot"
     REPLICA = "replica"
 
@@ -1437,6 +1602,13 @@ class SnapshotRecover(BaseModel, extra="forbid"):
 
 
 class StateRole(str, Enum):
+    """
+    Role of the peer in the consensus
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     FOLLOWER = "Follower"
     CANDIDATE = "Candidate"
     LEADER = "Leader"
@@ -1467,6 +1639,32 @@ class TokenizerType(str, Enum):
     PREFIX = "prefix"
     WHITESPACE = "whitespace"
     WORD = "word"
+    MULTILINGUAL = "multilingual"
+
+
+class TrackerStatusOneOf(str, Enum):
+    OPTIMIZING = "optimizing"
+    DONE = "done"
+
+
+class TrackerStatusOneOf1(BaseModel, extra="forbid"):
+    cancelled: str = Field(..., description="")
+
+
+class TrackerStatusOneOf2(BaseModel, extra="forbid"):
+    error: str = Field(..., description="")
+
+
+class TrackerTelemetry(BaseModel, extra="forbid"):
+    """
+    Tracker object used in telemetry
+    """
+
+    name: str = Field(..., description="Name of the optimizer")
+    segment_ids: List[int] = Field(..., description="Segment IDs being optimized")
+    status: "TrackerStatus" = Field(..., description="Tracker object used in telemetry")
+    start_at: datetime = Field(..., description="Start time of the optimizer")
+    end_at: Optional[datetime] = Field(default=None, description="End time of the optimizer")
 
 
 class UpdateCollection(BaseModel, extra="forbid"):
@@ -1474,13 +1672,27 @@ class UpdateCollection(BaseModel, extra="forbid"):
     Operation for updating parameters of the existing collection
     """
 
+    vectors: Optional["VectorsConfigDiff"] = Field(
+        default=None,
+        description="Map of vector data parameters to update for each named vector. To update parameters in a collection having a single unnamed vector, use an empty string as name.",
+    )
     optimizers_config: Optional["OptimizersConfigDiff"] = Field(
         default=None,
-        description="Custom params for Optimizers.  If none - values from service configuration file are used. This operation is blocking, it will only proceed ones all current optimizations are complete",
+        description="Custom params for Optimizers.  If none - it is left unchanged. This operation is blocking, it will only proceed once all current optimizations are complete",
     )
     params: Optional["CollectionParamsDiff"] = Field(
-        default=None, description="Collection base params.  If none - values from service configuration file are used."
+        default=None, description="Collection base params. If none - it is left unchanged."
     )
+    hnsw_config: Optional["HnswConfigDiff"] = Field(
+        default=None, description="HNSW parameters to update for the collection index. If none - it is left unchanged."
+    )
+    quantization_config: Optional["QuantizationConfigDiff"] = Field(
+        default=None, description="Quantization parameters to update. If none - it is left unchanged."
+    )
+
+
+class UpdateOperations(BaseModel, extra="forbid"):
+    operations: List["UpdateOperation"] = Field(..., description="")
 
 
 class UpdateResult(BaseModel, extra="forbid"):
@@ -1489,6 +1701,13 @@ class UpdateResult(BaseModel, extra="forbid"):
 
 
 class UpdateStatus(str, Enum):
+    """
+    `Acknowledged` - Request is saved to WAL and will be process in a queue. `Completed` - Request is completed, changes are actual.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     ACKNOWLEDGED = "acknowledged"
     COMPLETED = "completed"
 
@@ -1497,6 +1716,14 @@ class UpdateVectors(BaseModel, extra="forbid"):
     points: List["PointVectors"] = Field(..., description="Points with named vectors")
 
 
+class UpdateVectorsOperation(BaseModel, extra="forbid"):
+    update_vectors: "UpdateVectors" = Field(..., description="")
+
+
+class UpsertOperation(BaseModel, extra="forbid"):
+    upsert: "PointInsertOperations" = Field(..., description="")
+
+
 class ValuesCount(BaseModel, extra="forbid"):
     """
     Values count filter request
@@ -1522,6 +1749,12 @@ class VectorDataConfig(BaseModel, extra="forbid"):
     )
 
 
+class VectorDataInfo(BaseModel, extra="forbid"):
+    num_vectors: int = Field(..., description="")
+    num_indexed_vectors: int = Field(..., description="")
+    num_deleted_vectors: int = Field(..., description="")
+
+
 class VectorIndexSearchesTelemetry(BaseModel, extra="forbid"):
     index_name: Optional[str] = Field(default=None, description="")
     unfiltered_plain: "OperationDurationStatistics" = Field(..., description="")
@@ -1554,15 +1787,48 @@ class VectorParams(BaseModel, extra="forbid"):
     )
 
 
+class VectorParamsDiff(BaseModel, extra="forbid"):
+    hnsw_config: Optional["HnswConfigDiff"] = Field(
+        default=None, description="Update params for HNSW index. If empty object - it will be unset."
+    )
+    quantization_config: Optional["QuantizationConfigDiff"] = Field(
+        default=None, description="Update params for quantization. If none - it is left unchanged."
+    )
+    on_disk: Optional[bool] = Field(
+        default=None, description="If true, vectors are served from disk, improving RAM usage at the cost of latency"
+    )
+
+
 class VectorStorageTypeOneOf(str, Enum):
+    """
+    Storage in memory (RAM)  Will be very fast at the cost of consuming a lot of memory.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     MEMORY = "Memory"
 
 
 class VectorStorageTypeOneOf1(str, Enum):
+    """
+    Storage in mmap file, not appendable  Search performance is defined by disk speed and the fraction of vectors that fit in memory.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     MMAP = "Mmap"
 
 
 class VectorStorageTypeOneOf2(str, Enum):
+    """
+    Storage in chunked mmap files, appendable  Search performance is defined by disk speed and the fraction of vectors that fit in memory.
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     CHUNKEDMMAP = "ChunkedMmap"
 
 
@@ -1593,6 +1859,13 @@ class WithLookup(BaseModel, extra="forbid"):
 
 
 class WriteOrdering(str, Enum):
+    """
+    Defines write ordering guarantees for collection operations  * `weak` - write operations may be reordered, works faster, default  * `medium` - write operations go through dynamically selected leader, may be inconsistent for a short period of time in case of leader change  * `strong` - Write operations go through the permanent leader, consistent, but may be unavailable if leader is down
+    """
+
+    def __str__(self) -> str:
+        return str(self.value)
+
     WEAK = "weak"
     MEDIUM = "medium"
     STRONG = "strong"
@@ -1686,11 +1959,36 @@ PointsSelector = Union[
 QuantizationConfig = Union[
     ScalarQuantization,
     ProductQuantization,
+    BinaryQuantization,
+]
+QuantizationConfigDiff = Union[
+    ScalarQuantization,
+    ProductQuantization,
+    BinaryQuantization,
+    Disabled,
 ]
 ReadConsistency = Union[
     ReadConsistencyType,
     StrictInt,
 ]
+ShardSnapshotLocation = Union[
+    StrictStr,
+]
+TrackerStatus = Union[
+    TrackerStatusOneOf,
+    TrackerStatusOneOf1,
+    TrackerStatusOneOf2,
+]
+UpdateOperation = Union[
+    UpsertOperation,
+    DeleteOperation,
+    SetPayloadOperation,
+    OverwritePayloadOperation,
+    DeletePayloadOperation,
+    ClearPayloadOperation,
+    UpdateVectorsOperation,
+    DeleteVectorsOperation,
+]
 UsingVector = Union[
     StrictStr,
 ]
@@ -1724,6 +2022,10 @@ PayloadFieldSchema = Union[
     PayloadSchemaType,
     PayloadSchemaParams,
 ]
+RecommendExample = Union[
+    ExtendedPointId,
+    List[StrictFloat],
+]
 WithPayloadInterface = Union[
     PayloadSelector,
     List[StrictStr],
